@@ -1,6 +1,7 @@
 #include <stdlib.h>
 
-int main(void)
+int
+main(void)
 {
     abort();
 }
