@@ -51,7 +51,9 @@
 /* Non-standard but supported by at least gcc and clang */
 #define __TEST_PICOLIBC_FALLTHROUGH __attribute__((fallthrough))
 #else
-#define __TEST_PICOLIBC_FALLTHROUGH do { } while(0)
+#define __TEST_PICOLIBC_FALLTHROUGH \
+    do {                            \
+    } while (0)
 #endif
 
 #ifdef _TEST_LONG_DOUBLE
@@ -90,10 +92,12 @@ check_long_double(const char *name, int i, long double prec, long double expect,
 #ifdef __IO_LONG_DOUBLE
         printf("%s test %d got %La expect %La diff %La\n", name, i, result, expect, diff);
 #else
-        printf("%s test %d got %a expect %a diff %a\n", name, i, (double) result, (double) expect, (double) diff);
+        printf("%s test %d got %a expect %a diff %a\n", name, i, (double)result, (double)expect,
+               (double)diff);
 #endif
 #else
-//        printf("%s test %d got %.33Lg expect %.33Lg diff %.33Lg\n", name, i, result, expect, diff);
+        //        printf("%s test %d got %.33Lg expect %.33Lg diff %.33Lg\n", name, i, result,
+        //        expect, diff);
         printf("%s test %d got %La expect %La diff %La\n", name, i, result, expect, diff);
 #endif
         return 1;
@@ -124,24 +128,24 @@ check_long_long(const char *name, int i, long long expect, long long result)
 
 typedef CONST struct {
     CONST char *name;
-    int (*test)(void);
+    int         (*test)(void);
 } long_double_test_t;
 
 typedef CONST struct {
-    int line;
+    int         line;
     long double x;
     long double y;
 } long_double_test_f_f_t;
 
 typedef CONST struct {
-    int line;
+    int         line;
     long double x0;
     long double x1;
     long double y;
 } long_double_test_f_ff_t;
 
 typedef CONST struct {
-    int line;
+    int         line;
     long double x0;
     long double x1;
     long double x2;
@@ -149,16 +153,16 @@ typedef CONST struct {
 } long_double_test_f_fff_t;
 
 typedef CONST struct {
-    int line;
+    int         line;
     long double x0;
-    int x1;
+    int         x1;
     long double y;
 } long_double_test_f_fi_t;
 
 typedef CONST struct {
-    int line;
+    int         line;
     long double x;
-    long long y;
+    long long   y;
 } long_double_test_i_f_t;
 
 /*
@@ -170,22 +174,22 @@ typedef CONST struct {
 #define FMA_PREC 0
 #if LDBL_MANT_DIG == 64
 #define DEFAULT_PREC 0x1p-55L
-#define SQRTL_PREC 0x1.0p-63L
+#define SQRTL_PREC   0x1.0p-63L
 #define FULL_LONG_DOUBLE
 #elif LDBL_MANT_DIG == 113
 #define FULL_LONG_DOUBLE
 #define DEFAULT_PREC 0x1p-105L
-#define SQRTL_PREC 0x1.0p-112L
+#define SQRTL_PREC   0x1.0p-112L
 #elif LDBL_MANT_DIG == 106
 #define DEFAULT_PREC 0x1p-97L
-#define SQRTL_PREC 0x1.0p-105L
+#define SQRTL_PREC   0x1.0p-105L
 #define PART_LONG_DOUBLE
 #elif LDBL_MANT_DIG == 53
 #define DEFAULT_PREC 0x1p-48L
-#define SQRTL_PREC 0x1.0p-52L
+#define SQRTL_PREC   0x1.0p-52L
 #elif LDBL_MANT_DIG == 24
 #define DEFAULT_PREC 0x1p-21L
-#define SQRTL_PREC 0x1.0p-23L
+#define SQRTL_PREC   0x1.0p-23L
 #else
 #error unsupported long double
 #endif
@@ -208,44 +212,32 @@ typedef CONST struct {
 
 #include "long_double_vec.h"
 
-#if !defined(__PICOLIBC__) || (defined(__IO_LONG_DOUBLE) && (defined(__TINY_STDIO) || defined(__IO_FLOATING_POINT)))
+#if !defined(__PICOLIBC__) || defined(__IO_LONG_DOUBLE)
 #define TEST_IO_LONG_DOUBLE
 #endif
 
-#if defined(__PICOLIBC__) && defined(__m68k__) && !defined(__TINY_STDIO)
-#undef TEST_IO_LONG_DOUBLE
-#endif
-
-#if defined(__PICOLIBC__) && !defined(__TINY_STDIO) && __LDBL_MANT_DIG__ != 64
-#undef TEST_IO_LONG_DOUBLE
-#endif
-
 #ifdef TEST_IO_LONG_DOUBLE
 static const long double vals[] = {
-    1.0L,
-    0x1.8p0L,
-    3.141592653589793238462643383279502884197169L,
-    0.0L,
-    1.0L/0.0L,
-    0.0L/0.0L,
+    1.0L, 0x1.8p0L, 3.141592653589793238462643383279502884197169L, 0.0L, 1.0L / 0.0L, 0.0L / 0.0L,
 };
 
-#define NVALS   (sizeof(vals)/sizeof(vals[0]))
+#define NVALS (sizeof(vals) / sizeof(vals[0]))
 
 static long double
 naive_strtold(const char *buf)
 {
     long double v = 0.0L;
-    long exp = 0;
+    long        exp = 0;
     long double frac_mul;
-    long exp_sign = 1;
+    long        exp_sign = 1;
     long double base = 10.0L;
-    char c;
+    char        c;
     enum {
         LDOUBLE_INT,
         LDOUBLE_FRAC,
         LDOUBLE_EXP,
-    } state = LDOUBLE_INT;
+    } state
+        = LDOUBLE_INT;
 
     if (strncmp(buf, "0x", 2) == 0) {
         base = 16.0L;
@@ -281,8 +273,16 @@ naive_strtold(const char *buf)
                 continue;
             }
             return -(long double)INFINITY;
-        case '0': case '1': case '2': case '3': case '4':
-        case '5': case '6': case '7': case '8': case '9':
+        case '0':
+        case '1':
+        case '2':
+        case '3':
+        case '4':
+        case '5':
+        case '6':
+        case '7':
+        case '8':
+        case '9':
             digit = c - '0';
             break;
         case 'E':
@@ -301,8 +301,11 @@ naive_strtold(const char *buf)
                 return -(long double)INFINITY;
             }
             __TEST_PICOLIBC_FALLTHROUGH;
-        case 'A': case 'B': case 'C':
-        case 'D': case 'F':
+        case 'A':
+        case 'B':
+        case 'C':
+        case 'D':
+        case 'F':
             if (state == LDOUBLE_INT || state == LDOUBLE_FRAC) {
                 digit = c - 'A' + 10;
                 break;
@@ -317,8 +320,11 @@ naive_strtold(const char *buf)
                 return -(long double)INFINITY;
             }
             __TEST_PICOLIBC_FALLTHROUGH;
-        case 'a': case 'b': case 'c':
-        case 'd': case 'f':
+        case 'a':
+        case 'b':
+        case 'c':
+        case 'd':
+        case 'f':
             if (state == LDOUBLE_INT || state == LDOUBLE_FRAC) {
                 digit = c - 'a' + 10;
                 break;
@@ -341,8 +347,8 @@ naive_strtold(const char *buf)
         }
     }
     if (base == 10.0L) {
-        long etop = exp / 2;
-        long ebot = exp - etop;
+        long        etop = exp / 2;
+        long        ebot = exp - etop;
         long double epow_top = powl(10.0L, etop * exp_sign);
         long double epow_bot = powl(10.0L, ebot * exp_sign);
         long double vpow = v * epow_top;
@@ -352,9 +358,12 @@ naive_strtold(const char *buf)
         return ldexpl(v, exp * exp_sign);
 }
 
-static const char * const formats[] = { "%La", "%.30Le", };
+static const char * const formats[] = {
+    "%La",
+    "%.30Le",
+};
 
-#define NFMTS (sizeof (formats)/sizeof(formats[0]))
+#define NFMTS (sizeof(formats) / sizeof(formats[0]))
 
 static bool
 close(long double have, long double want, long double max_error)
@@ -397,40 +406,39 @@ static const int test_exp[] = {
     __LDBL_MAX_EXP__ + 1,
 };
 
-#define NEXPS (sizeof (test_exp)/ sizeof(test_exp[0]))
+#define NEXPS (sizeof(test_exp) / sizeof(test_exp[0]))
 
 /*
  * For 64-bit values, we may have exact conversions. Otherwise, allow
  * some error
  */
 #ifdef __IO_FLOAT_EXACT
-# if __SIZEOF_LONG_DOUBLE__ == 8
-#  define MAX_DECIMAL_ERROR       0
-# else
-#  define MAX_DECIMAL_ERROR     1e-10L
-# endif
+#if __SIZEOF_LONG_DOUBLE__ == 8
+#define MAX_DECIMAL_ERROR 0
 #else
-# if __SIZEOF_LONG_DOUBLE__ == 4
-#  define MAX_DECIMAL_ERROR       1e-2L
-# elif __SIZEOF_LONG_DOUBLE__ == 8
-#  define MAX_DECIMAL_ERROR       1e-5L
-# else
-#  define MAX_DECIMAL_ERROR       1e-10L
-# endif
+#define MAX_DECIMAL_ERROR 1e-10L
+#endif
+#else
+#if __SIZEOF_LONG_DOUBLE__ == 4
+#define MAX_DECIMAL_ERROR 1e-2L
+#elif __SIZEOF_LONG_DOUBLE__ == 8
+#define MAX_DECIMAL_ERROR 1e-5L
+#else
+#define MAX_DECIMAL_ERROR 1e-10L
+#endif
 #endif
 
 static int
 test_io(void)
 {
-    unsigned e;
-    int result = 0;
-    char buf[80];
-    unsigned i, j;
+    unsigned    e;
+    int         result = 0;
+    char        buf[80];
+    unsigned    i, j;
     long double max_error, max_error_naive;
-    char *end;
+    char       *end;
 
-    for (e = 0; e < NEXPS; e++)
-    {
+    for (e = 0; e < NEXPS; e++) {
         for (i = 0; i < NVALS; i++) {
 
             long double v, r;
@@ -449,7 +457,8 @@ test_io(void)
                 sprintf(buf, formats[j], v);
                 if (isinf(v)) {
                     if (strcmp(buf, "inf") != 0) {
-                        printf("test_io i %d val %La exp %d: is %s should be inf\n", i, vals[i], test_exp[e], buf);
+                        printf("test_io i %d val %La exp %d: is %s should be inf\n", i, vals[i],
+                               test_exp[e], buf);
 #ifdef __RX__
                         printf("ignoring error on RX\n");
 #else
@@ -461,6 +470,12 @@ test_io(void)
                         printf("test_io is %s should be nan\n", buf);
 #ifdef __RX__
                         printf("ignoring error on RX\n");
+#elif __HEXAGON_ARCH__
+                        if (strcmp(buf, "-nan") != 0)
+                            result++;
+                        // Hexagon instructions always generate negative nan i.e 0xFFFFFFFF
+                        else
+                            printf("ignore negative nan on Hexagon\n");
 #else
                         result++;
 #endif
@@ -468,34 +483,38 @@ test_io(void)
                 } else {
                     r = naive_strtold(buf);
                     if (!close(r, v, max_error_naive)) {
-                        printf("test_io naive i %d val %La exp %d: \"%s\", is %La should be %La\n", i, vals[i], test_exp[e], buf, r, v);
+                        printf("test_io naive i %d val %La exp %d: \"%s\", is %La should be %La\n",
+                               i, vals[i], test_exp[e], buf, r, v);
 #ifdef __RX__
                         if (!isnormal(v) || !isnormal(r))
                             printf("ignoring error on RX\n");
                         else
 #endif
-                        result++;
+                            result++;
                     }
                 }
                 sscanf(buf, "%Lf", &r);
                 if (!close(r, v, max_error) && !(isnan(v) && isnan(r))) {
-                    printf("test_io scanf i %d val %La exp %d: \"%s\", is %La should be %La\n", i, vals[i], test_exp[e], buf, r, v);
+                    printf("test_io scanf i %d val %La exp %d: \"%s\", is %La should be %La\n", i,
+                           vals[i], test_exp[e], buf, r, v);
 #ifdef __RX__
                     if (!isnormal(v) || !isnormal(r))
                         printf("ignoring error on RX\n");
                     else
 #endif
-                    result++;
+                        result++;
                 }
                 r = strtold(buf, &end);
-                if ((!close(r, v, max_error) && !(isnan(v) && isnan(r)))|| end != buf + strlen(buf)) {
-                    printf("test_io strtold i %d val %La exp %d: \"%s\", is %La should be %La\n", i, vals[i], test_exp[e], buf, r, v);
+                if ((!close(r, v, max_error) && !(isnan(v) && isnan(r)))
+                    || end != buf + strlen(buf)) {
+                    printf("test_io strtold i %d val %La exp %d: \"%s\", is %La should be %La\n", i,
+                           vals[i], test_exp[e], buf, r, v);
 #ifdef __RX__
                     if (!isnormal(v) || !isnormal(r))
                         printf("ignoring error on RX\n");
                     else
 #endif
-                    result++;
+                        result++;
                 }
             }
         }
@@ -504,46 +523,45 @@ test_io(void)
 }
 #endif
 
-union double_long
-{
-  double d;
-  struct {
-      long upper;
-      unsigned long lower;
+union double_long {
+    double d;
+    struct {
+        long          upper;
+        unsigned long lower;
     } l;
 };
 
 union float_long {
-  float f;
-  long l;
+    float f;
+    long  l;
 };
 
 #ifdef __MSP430__
-#define STEP_I  8
-#define STEP_J  4
+#define STEP_I 8
+#define STEP_J 4
 #else
-#define STEP_I  1
-#define STEP_J  1
+#define STEP_I 1
+#define STEP_J 1
 #endif
 
 static int
 test_conv(void)
 {
     union double_long dl;
-    long double ld;
-    double d;
-    union float_long fl;
-    float f;
-    long i;
-    unsigned long j, k;
-    int ret = 0;
+    long double       ld;
+    double            d;
+    union float_long  fl;
+    float             f;
+    long              i;
+    unsigned long     j, k;
+    int               ret = 0;
 
     for (i = 0; i <= 0xffff; i += STEP_I) {
         for (j = 0; j < 0xf; j += STEP_J) {
             for (k = 0; k < 0x2; k++) {
-                dl.l.upper = (unsigned long) i << 16;
+                dl.l.upper = (unsigned long)i << 16;
                 dl.l.lower = (j << 28) | k;
-                ld = (long double) dl.d;
+                ld = (long double)dl.d;
                 if (fabsl(ld) > 1) {
                     ld /= 2;
                     ld *= 2;
@@ -551,7 +569,7 @@ test_conv(void)
                     ld *= 2;
                     ld /= 2;
                 }
-                d = (double) ld;
+                d = (double)ld;
                 if (isnan(d) && isnan(dl.d))
                     ;
                 else if (d != dl.d) {
@@ -559,13 +577,13 @@ test_conv(void)
                     ret++;
                 }
 
-                fl.l = ((unsigned long) i << 16) | k;
-                ld = (long double) fl.f;
-                f = (float) ld;
+                fl.l = ((unsigned long)i << 16) | k;
+                ld = (long double)fl.f;
+                f = (float)ld;
                 if (isnan(f) && isnan(fl.f))
                     ;
                 else if (f != fl.f) {
-                    printf("convert float %a -> %La -> %a\n", (double) fl.f, ld, (double) f);
+                    printf("convert float %a -> %La -> %a\n", (double)fl.f, ld, (double)f);
                     ret++;
                 }
             }
@@ -574,9 +592,10 @@ test_conv(void)
     return ret;
 }
 
-int main(void)
+int
+main(void)
 {
-    int result = 0;
+    int          result = 0;
     unsigned int i;
 
 #ifdef __mcffpu__
@@ -606,7 +625,8 @@ int main(void)
 }
 
 #else
-int main(void)
+int
+main(void)
 {
     printf("no long double support\n");
     return 0;
