@@ -40,52 +40,51 @@
 #define TEST_FILE_NAME "SEMIREN.TXT"
 #endif
 
-#define TEST_FILE_NAME_1	"A" TEST_FILE_NAME
-#define TEST_FILE_NAME_2	"B" TEST_FILE_NAME
+#define TEST_FILE_NAME_1 "A" TEST_FILE_NAME
+#define TEST_FILE_NAME_2 "B" TEST_FILE_NAME
 
 int
 main(void)
 {
-	int		fd;
-	int		code = 0;
-	int		ret;
+    int fd;
+    int code = 0;
+    int ret;
 
-	fd = sys_semihost_open(TEST_FILE_NAME_1, SH_OPEN_W);
-	if (fd < 0) {
-		printf("open %s failed\n", TEST_FILE_NAME_1);
-		exit(1);
-	}
-	ret = sys_semihost_close(fd);
-	fd = -1;
-	if (ret != 0) {
-		printf("close failed %d %d\n", ret, sys_semihost_errno());
-		code = 2;
-		goto bail1;
-	}
-	ret = sys_semihost_rename(TEST_FILE_NAME_1, TEST_FILE_NAME_2);
-	if (ret != 0) {
-		printf("rename %s -> %s failed %d %d\n",
-		       TEST_FILE_NAME_1, TEST_FILE_NAME_2,
-		       ret, sys_semihost_errno());
-		code = 3;
-		goto bail1;
-	}
-	fd = sys_semihost_open(TEST_FILE_NAME_1, SH_OPEN_R);
-	if (fd >= 0) {
-		printf("open %s should have failed\n", TEST_FILE_NAME_1);
-		code = 3;
-		goto bail1;
-	}
-	fd = sys_semihost_open(TEST_FILE_NAME_2, SH_OPEN_R);
-	if (fd < 0) {
-		printf("open %s failed\n", TEST_FILE_NAME_2);
-		code = 3;
-		goto bail1;
-	}
+    fd = sys_semihost_open(TEST_FILE_NAME_1, SH_OPEN_W);
+    if (fd < 0) {
+        printf("open %s failed\n", TEST_FILE_NAME_1);
+        exit(1);
+    }
+    ret = sys_semihost_close(fd);
+    fd = -1;
+    if (ret != 0) {
+        printf("close failed %d %d\n", ret, sys_semihost_errno());
+        code = 2;
+        goto bail1;
+    }
+    ret = sys_semihost_rename(TEST_FILE_NAME_1, TEST_FILE_NAME_2);
+    if (ret != 0) {
+        printf("rename %s -> %s failed %d %d\n", TEST_FILE_NAME_1, TEST_FILE_NAME_2, ret,
+               sys_semihost_errno());
+        code = 3;
+        goto bail1;
+    }
+    fd = sys_semihost_open(TEST_FILE_NAME_1, SH_OPEN_R);
+    if (fd >= 0) {
+        printf("open %s should have failed\n", TEST_FILE_NAME_1);
+        code = 3;
+        goto bail1;
+    }
+    fd = sys_semihost_open(TEST_FILE_NAME_2, SH_OPEN_R);
+    if (fd < 0) {
+        printf("open %s failed\n", TEST_FILE_NAME_2);
+        code = 3;
+        goto bail1;
+    }
 bail1:
-	if (fd >= 0)
-		(void) sys_semihost_close(fd);
-	(void) sys_semihost_remove(TEST_FILE_NAME_1);
-	(void) sys_semihost_remove(TEST_FILE_NAME_2);
-	exit(code);
+    if (fd >= 0)
+        (void)sys_semihost_close(fd);
+    (void)sys_semihost_remove(TEST_FILE_NAME_1);
+    (void)sys_semihost_remove(TEST_FILE_NAME_2);
+    exit(code);
 }
